@@ -121,7 +121,9 @@ class AsyncAnalytics:
 
         latest = r.json()["info"]["version"]
         if analytix.__version__ != latest:
-            log.warning(f"A newer version of analytix is available (v{latest})")
+            log.warning(
+                f"You do not have the latest stable version of analytix (v{latest})"
+            )
 
         self._checked_for_update = True
         return t.cast(str, latest)
@@ -159,13 +161,7 @@ class AsyncAnalytics:
         r = await self._session.get(
             analytix.OAUTH_CHECK_URL + self._tokens.access_token
         )
-        if r.is_error:
-            # This seems to fail sometimes when a token is invalid, so
-            # just refresh it -- we probably need to anyways.
-            return True
-
-        # If it's only got a few minutes on it, might as well refresh.
-        return int(r.json().get("expires_in", 0)) < 300
+        return r.is_error
 
     async def refresh_access_token(self) -> None:
         """Refresh the access token."""
@@ -249,6 +245,7 @@ class AsyncAnalytics:
         force_authorisation: bool = False,
         skip_update_check: bool = False,
         skip_refresh_check: bool = False,
+        token_path: pathlib.Path | str = ".",
     ) -> Report:
         """Retrieves a report from the YouTube Analytics API.
 
@@ -312,6 +309,14 @@ class AsyncAnalytics:
                 ``False``.
             skip_refresh_token:
                 Whether to skip token refreshing. Defaults to ``False``.
+            token_path:
+                The path to the token file or the directory the token
+                file is or should be stored in. If this is not provided,
+                this defaults to the current directory, and if a
+                directory is passed, the file is given the name
+                "tokens.json".
+
+                .. versionadded:: 3.3.0
 
         Returns:
             An instance for working with retrieved data.
@@ -341,7 +346,7 @@ class AsyncAnalytics:
             )
 
         if not self.authorised or force_authorisation:
-            await self.authorise(force=force_authorisation)
+            await self.authorise(token_path=token_path, force=force_authorisation)
 
         if (not skip_refresh_check) and await self.needs_refresh():
             await self.refresh_access_token()
